import pytest

import abjad
from abjad import math

values = [
    ("-A1", -1, "-A1"),
    ("-A10", -17, "-A10"),
    ("-A11", -18, "-A11"),
    ("-A12", -20, "-A12"),
    ("-A13", -22, "-A13"),
    ("-A14", -24, "-A14"),
    ("-A2", -3, "-A2"),
    ("-A3", -5, "-A3"),
    ("-A4", -6, "-A4"),
    ("-A5", -8, "-A5"),
    ("-A6", -10, "-A6"),
    ("-A7", -12, "-A7"),
    ("-A8", -13, "-A8"),
    ("-A9", -15, "-A9"),
    ("-AA1", -2, "-AA1"),
    ("-AA10", -18, "-AA10"),
    ("-AA11", -19, "-AA11"),
    ("-AA12", -21, "-AA12"),
    ("-AA13", -23, "-AA13"),
    ("-AA14", -25, "-AA14"),
    ("-AA2", -4, "-AA2"),
    ("-AA3", -6, "-AA3"),
    ("-AA4", -7, "-AA4"),
    ("-AA5", -9, "-AA5"),
    ("-AA6", -11, "-AA6"),
    ("-AA7", -13, "-AA7"),
    ("-AA8", -14, "-AA8"),
    ("-AA9", -16, "-AA9"),
    ("-AAA1", -3, "-AAA1"),
    ("-AAA10", -19, "-AAA10"),
    ("-AAA11", -20, "-AAA11"),
    ("-AAA12", -22, "-AAA12"),
    ("-AAA13", -24, "-AAA13"),
    ("-AAA14", -26, "-AAA14"),
    ("-AAA2", -5, "-AAA2"),
    ("-AAA3", -7, "-AAA3"),
    ("-AAA4", -8, "-AAA4"),
    ("-AAA5", -10, "-AAA5"),
    ("-AAA6", -12, "-AAA6"),
    ("-AAA7", -14, "-AAA7"),
    ("-AAA8", -15, "-AAA8"),
    ("-AAA9", -17, "-AAA9"),
    ("-M10", -16, "-M10"),
    ("-M13", -21, "-M13"),
    ("-M2", -2, "-M2"),
    ("-M3", -4, "-M3"),
    ("-M6", -9, "-M6"),
    ("-M7", -11, "-M7"),
    ("-M9", -14, "-M9"),
    ("-P1", -0, "P1"),
    ("-P11", -17, "-P11"),
    ("-P12", -19, "-P12"),
    ("-P15", -24, "-P15"),
    ("-P4", -5, "-P4"),
    ("-P5", -7, "-P5"),
    ("-P8", -12, "-P8"),
    ("-P8", -12, "-P8"),
    ("-d1", -1, "-d1"),
    ("-d10", -14, "-d10"),
    ("-d11", -16, "-d11"),
    ("-d12", -18, "-d12"),
    ("-d13", -19, "-d13"),
    ("-d14", -21, "-d14"),
    ("-d2", -0, "-d2"),
    ("-d3", -2, "-d3"),
    ("-d4", -4, "-d4"),
    ("-d5", -6, "-d5"),
    ("-d6", -7, "-d6"),
    ("-d7", -9, "-d7"),
    ("-d8", -11, "-d8"),
    ("-d9", -12, "-d9"),
    ("-dd1", -2, "-dd1"),
    ("-dd10", -13, "-dd10"),
    ("-dd11", -15, "-dd11"),
    ("-dd12", -17, "-dd12"),
    ("-dd13", -18, "-dd13"),
    ("-dd14", -20, "-dd14"),
    ("-dd2", 1, "-dd2"),
    ("-dd3", -1, "-dd3"),
    ("-dd4", -3, "-dd4"),
    ("-dd5", -5, "-dd5"),
    ("-dd6", -6, "-dd6"),
    ("-dd7", -8, "-dd7"),
    ("-dd8", -10, "-dd8"),
    ("-dd9", -11, "-dd9"),
    ("-ddd1", -3, "-ddd1"),
    ("-ddd10", -12, "-ddd10"),
    ("-ddd11", -14, "-ddd11"),
    ("-ddd12", -16, "-ddd12"),
    ("-ddd13", -17, "-ddd13"),
    ("-ddd14", -19, "-ddd14"),
    ("-ddd2", 2, "-ddd2"),
    ("-ddd3", 0, "-ddd3"),
    ("-ddd4", -2, "-ddd4"),
    ("-ddd5", -4, "-ddd5"),
    ("-ddd6", -5, "-ddd6"),
    ("-ddd7", -7, "-ddd7"),
    ("-ddd8", -9, "-ddd8"),
    ("-ddd9", -10, "-ddd9"),
    ("-m10", -15, "-m10"),
    ("-m13", -20, "-m13"),
    ("-m14", -22, "-m14"),
    ("-m2", -1, "-m2"),
    ("-m3", -3, "-m3"),
    ("-m6", -8, "-m6"),
    ("-m7", -10, "-m7"),
    ("-m9", -13, "-m9"),
    ("A1", 1, "+A1"),
    ("A10", 17, "+A10"),
    ("A11", 18, "+A11"),
    ("A12", 20, "+A12"),
    ("A13", 22, "+A13"),
    ("A14", 24, "+A14"),
    ("A2", 3, "+A2"),
    ("A3", 5, "+A3"),
    ("A4", 6, "+A4"),
    ("A5", 8, "+A5"),
    ("A6", 10, "+A6"),
    ("A7", 12, "+A7"),
    ("A8", 13, "+A8"),
    ("A9", 15, "+A9"),
    ("AA1", 2, "+AA1"),
    ("AA10", 18, "+AA10"),
    ("AA11", 19, "+AA11"),
    ("AA12", 21, "+AA12"),
    ("AA13", 23, "+AA13"),
    ("AA14", 25, "+AA14"),
    ("AA2", 4, "+AA2"),
    ("AA3", 6, "+AA3"),
    ("AA4", 7, "+AA4"),
    ("AA5", 9, "+AA5"),
    ("AA6", 11, "+AA6"),
    ("AA7", 13, "+AA7"),
    ("AA8", 14, "+AA8"),
    ("AA9", 16, "+AA9"),
    ("AAA1", 3, "+AAA1"),
    ("AAA10", 19, "+AAA10"),
    ("AAA11", 20, "+AAA11"),
    ("AAA12", 22, "+AAA12"),
    ("AAA13", 24, "+AAA13"),
    ("AAA14", 26, "+AAA14"),
    ("AAA2", 5, "+AAA2"),
    ("AAA3", 7, "+AAA3"),
    ("AAA4", 8, "+AAA4"),
    ("AAA5", 10, "+AAA5"),
    ("AAA6", 12, "+AAA6"),
    ("AAA7", 14, "+AAA7"),
    ("AAA8", 15, "+AAA8"),
    ("AAA9", 17, "+AAA9"),
    ("M10", 16, "+M10"),
    ("M13", 21, "+M13"),
    ("M14", 23, "+M14"),
    ("M2", 2, "+M2"),
    ("M3", 4, "+M3"),
    ("M6", 9, "+M6"),
    ("M7", 11, "+M7"),
    ("M9", 14, "+M9"),
    ("P1", 0, "P1"),
    ("P11", 17, "+P11"),
    ("P12", 19, "+P12"),
    ("P15", 24, "+P15"),
    ("P4", 5, "+P4"),
    ("P5", 7, "+P5"),
    ("P8", 12, "+P8"),
    ("d1", 1, "+d1"),
    ("d10", 14, "+d10"),
    ("d11", 16, "+d11"),
    ("d12", 18, "+d12"),
    ("d13", 19, "+d13"),
    ("d14", 21, "+d14"),
    ("d2", 0, "+d2"),
    ("d3", 2, "+d3"),
    ("d4", 4, "+d4"),
    ("d5", 6, "+d5"),
    ("d6", 7, "+d6"),
    ("d7", 9, "+d7"),
    ("d8", 11, "+d8"),
    ("d9", 12, "+d9"),
    ("dd1", 2, "+dd1"),
    ("dd10", 13, "+dd10"),
    ("dd11", 15, "+dd11"),
    ("dd12", 17, "+dd12"),
    ("dd13", 18, "+dd13"),
    ("dd14", 20, "+dd14"),
    ("dd2", -1, "+dd2"),
    ("dd3", 1, "+dd3"),
    ("dd4", 3, "+dd4"),
    ("dd5", 5, "+dd5"),
    ("dd6", 6, "+dd6"),
    ("dd7", 8, "+dd7"),
    ("dd8", 10, "+dd8"),
    ("dd9", 11, "+dd9"),
    ("ddd1", 3, "+ddd1"),
    ("ddd10", 12, "+ddd10"),
    ("ddd11", 14, "+ddd11"),
    ("ddd12", 16, "+ddd12"),
    ("ddd13", 17, "+ddd13"),
    ("ddd14", 19, "+ddd14"),
    ("ddd2", -2, "+ddd2"),
    ("ddd3", 0, "+ddd3"),
    ("ddd4", 2, "+ddd4"),
    ("ddd5", 4, "+ddd5"),
    ("ddd6", 5, "+ddd6"),
    ("ddd7", 7, "+ddd7"),
    ("ddd8", 9, "+ddd8"),
    ("ddd9", 10, "+ddd9"),
    ("m10", 15, "+m10"),
    ("m13", 20, "+m13"),
    ("m14", 22, "+m14"),
    ("m2", 1, "+m2"),
    ("m3", 3, "+m3"),
    ("m6", 8, "+m6"),
    ("m7", 10, "+m7"),
    ("m9", 13, "+m9"),
    (("M", 1), ValueError, None),
    (("M", 4), ValueError, None),
    (("M", 5), ValueError, None),
    (("P", 2), ValueError, None),
    (("P", 3), ValueError, None),
    (("P", 6), ValueError, None),
    (("P", 7), ValueError, None),
    (("m", 1), ValueError, None),
    (("m", 4), ValueError, None),
    (("m", 5), ValueError, None),
    (-1, -1, "-m2"),
    (-10, -10, "-m7"),
    (-11, -11, "-M7"),
    (-12, -12, "-P8"),
    (-13, -13, "-m9"),
    (-14, -14, "-M9"),
    (-15, -15, "-m10"),
    (-16, -16, "-M10"),
    (-17, -17, "-P11"),
    (-18, -18, "-d12"),
    (-19, -19, "-P12"),
    (-2, -2, "-M2"),
    (-20, -20, "-m13"),
    (-21, -21, "-M13"),
    (-22, -22, "-m14"),
    (-23, -23, "-M14"),
    (-24, -24, "-P15"),
    (-3, -3, "-m3"),
    (-4, -4, "-M3"),
    (-5, -5, "-P4"),
    (-6, -6, "-d5"),
    (-7, -7, "-P5"),
    (-8, -8, "-m6"),
    (-9, -9, "-M6"),
    (0, 0, "P1"),
    (1, 1, "+m2"),
    (10, 10, "+m7"),
    (11, 11, "+M7"),
    (12, 12, "+P8"),
    (13, 13, "+m9"),
    (14, 14, "+M9"),
    (15, 15, "+m10"),
    (16, 16, "+M10"),
    (17, 17, "+P11"),
    (18, 18, "+d12"),
    (19, 19, "+P12"),
    (2, 2, "+M2"),
    (20, 20, "+m13"),
    (21, 21, "+M13"),
    (22, 22, "+m14"),
    (23, 23, "+M14"),
    (24, 24, "+P15"),
    (3, 3, "+m3"),
    (4, 4, "+M3"),
    (5, 5, "+P4"),
    (6, 6, "+d5"),
    (7, 7, "+P5"),
    (8, 8, "+m6"),
    (9, 9, "+M6"),
]


@pytest.mark.parametrize("input_, semitones, name", values)
def test_init(input_, semitones, name):
    class_ = abjad.NamedInterval
    if isinstance(semitones, type) and issubclass(semitones, Exception):
        with pytest.raises(semitones):
            class_(input_)
        return
    instance = class_(input_)
    assert float(instance) == semitones
    assert instance.name == name
    abjad.NamedInterval(instance)
    abjad.NumberedInterval(instance)
    abjad.NamedIntervalClass(instance)
    abjad.NumberedIntervalClass(instance)
    if isinstance(input_, str):
        group_dict = abjad.pitch._interval_name_abbreviation_regex.match(
            input_
        ).groupdict()
        inflected_up = class_(
            "{}{}{}{}".format(
                group_dict["direction"] or "",
                group_dict["quality"],
                "+",
                group_dict["number"],
            )
        )
        inflected_down = class_(
            "{}{}{}{}".format(
                group_dict["direction"] or "",
                group_dict["quality"],
                "~",
                group_dict["number"],
            )
        )
        if (math.sign(float(instance)) == instance.direction_number) and abs(
            instance.number
        ) != 1:
            direction = math.sign(float(instance))
            assert float(inflected_up) == (abs(float(instance)) + 0.5) * direction
            assert float(inflected_down) == (abs(float(instance)) - 0.5) * direction


"""
import abjad
import itertools

product = itertools.product(
    ["cff'", "ctqf'", "cf'", "cqf'", "c'", "cqs'", "cs'", "ctqs'", "css'"],
    [
        'c', 'd', 'e', 'f', 'g', 'a', 'b',
        "c'", "d'", "e'", "f'", "g'", "a'", "b'",
        "c''",
    ],
    ['ff', 'tqf', 'f', 'qf', '', 'qs', 's', 'tqs', 'ss'],
)

for x, y, z in product:
    print("({!r}, {!r}, ''),".format(
        x, str(abjad.abjad.NamedPitch(y, accidental=z)),
    ))
"""


values = [
    ("cff'", "cff", "-P8"),
    ("cff'", "ctqf", "-d+8"),
    ("cff'", "cf", "-d8"),
    ("cff'", "cqf", "-dd+8"),
    ("cff'", "c", "-dd8"),
    ("cff'", "cqs", "-ddd+8"),
    ("cff'", "cs", "-ddd8"),
    ("cff'", "ctqs", "-dddd+8"),
    ("cff'", "css", "-dddd8"),
    ("cff'", "dff", "-m7"),
    ("cff'", "dtqf", "-d+7"),
    ("cff'", "df", "-d7"),
    ("cff'", "dqf", "-dd+7"),
    ("cff'", "d", "-dd7"),
    ("cff'", "dqs", "-ddd+7"),
    ("cff'", "ds", "-ddd7"),
    ("cff'", "dtqs", "-dddd+7"),
    ("cff'", "dss", "-dddd7"),
    ("cff'", "eff", "-m6"),
    ("cff'", "etqf", "-d+6"),
    ("cff'", "ef", "-d6"),
    ("cff'", "eqf", "-dd+6"),
    ("cff'", "e", "-dd6"),
    ("cff'", "eqs", "-ddd+6"),
    ("cff'", "es", "-ddd6"),
    ("cff'", "etqs", "-dddd+6"),
    ("cff'", "ess", "-dddd6"),
    ("cff'", "fff", "-P5"),
    ("cff'", "ftqf", "-d+5"),
    ("cff'", "ff", "-d5"),
    ("cff'", "fqf", "-dd+5"),
    ("cff'", "f", "-dd5"),
    ("cff'", "fqs", "-ddd+5"),
    ("cff'", "fs", "-ddd5"),
    ("cff'", "ftqs", "-dddd+5"),
    ("cff'", "fss", "-dddd5"),
    ("cff'", "gff", "-P4"),
    ("cff'", "gtqf", "-d+4"),
    ("cff'", "gf", "-d4"),
    ("cff'", "gqf", "-dd+4"),
    ("cff'", "g", "-dd4"),
    ("cff'", "gqs", "-ddd+4"),
    ("cff'", "gs", "-ddd4"),
    ("cff'", "gtqs", "-dddd+4"),
    ("cff'", "gss", "-dddd4"),
    ("cff'", "aff", "-m3"),
    ("cff'", "atqf", "-d+3"),
    ("cff'", "af", "-d3"),
    ("cff'", "aqf", "-dd+3"),
    ("cff'", "a", "-dd3"),
    ("cff'", "aqs", "-ddd+3"),
    ("cff'", "as", "-ddd3"),
    ("cff'", "atqs", "-dddd+3"),
    ("cff'", "ass", "-dddd3"),
    ("cff'", "bff", "-m2"),
    ("cff'", "btqf", "-d+2"),
    ("cff'", "bf", "-d2"),
    ("cff'", "bqf", "-dd+2"),
    ("cff'", "b", "-dd2"),
    ("cff'", "bqs", "-ddd+2"),
    ("cff'", "bs", "-ddd2"),
    ("cff'", "btqs", "-dddd+2"),
    ("cff'", "bss", "-dddd2"),
    ("cff'", "cff'", "P1"),
    ("cff'", "ctqf'", "+P+1"),
    ("cff'", "cf'", "+A1"),
    ("cff'", "cqf'", "+A+1"),
    ("cff'", "c'", "+AA1"),
    ("cff'", "cqs'", "+AA+1"),
    ("cff'", "cs'", "+AAA1"),
    ("cff'", "ctqs'", "+AAA+1"),
    ("cff'", "css'", "+AAAA1"),
    ("cff'", "dff'", "+M2"),
    ("cff'", "dtqf'", "+M+2"),
    ("cff'", "df'", "+A2"),
    ("cff'", "dqf'", "+A+2"),
    ("cff'", "d'", "+AA2"),
    ("cff'", "dqs'", "+AA+2"),
    ("cff'", "ds'", "+AAA2"),
    ("cff'", "dtqs'", "+AAA+2"),
    ("cff'", "dss'", "+AAAA2"),
    ("cff'", "eff'", "+M3"),
    ("cff'", "etqf'", "+M+3"),
    ("cff'", "ef'", "+A3"),
    ("cff'", "eqf'", "+A+3"),
    ("cff'", "e'", "+AA3"),
    ("cff'", "eqs'", "+AA+3"),
    ("cff'", "es'", "+AAA3"),
    ("cff'", "etqs'", "+AAA+3"),
    ("cff'", "ess'", "+AAAA3"),
    ("cff'", "fff'", "+P4"),
    ("cff'", "ftqf'", "+P+4"),
    ("cff'", "ff'", "+A4"),
    ("cff'", "fqf'", "+A+4"),
    ("cff'", "f'", "+AA4"),
    ("cff'", "fqs'", "+AA+4"),
    ("cff'", "fs'", "+AAA4"),
    ("cff'", "ftqs'", "+AAA+4"),
    ("cff'", "fss'", "+AAAA4"),
    ("cff'", "gff'", "+P5"),
    ("cff'", "gtqf'", "+P+5"),
    ("cff'", "gf'", "+A5"),
    ("cff'", "gqf'", "+A+5"),
    ("cff'", "g'", "+AA5"),
    ("cff'", "gqs'", "+AA+5"),
    ("cff'", "gs'", "+AAA5"),
    ("cff'", "gtqs'", "+AAA+5"),
    ("cff'", "gss'", "+AAAA5"),
    ("cff'", "aff'", "+M6"),
    ("cff'", "atqf'", "+M+6"),
    ("cff'", "af'", "+A6"),
    ("cff'", "aqf'", "+A+6"),
    ("cff'", "a'", "+AA6"),
    ("cff'", "aqs'", "+AA+6"),
    ("cff'", "as'", "+AAA6"),
    ("cff'", "atqs'", "+AAA+6"),
    ("cff'", "ass'", "+AAAA6"),
    ("cff'", "bff'", "+M7"),
    ("cff'", "btqf'", "+M+7"),
    ("cff'", "bf'", "+A7"),
    ("cff'", "bqf'", "+A+7"),
    ("cff'", "b'", "+AA7"),
    ("cff'", "bqs'", "+AA+7"),
    ("cff'", "bs'", "+AAA7"),
    ("cff'", "btqs'", "+AAA+7"),
    ("cff'", "bss'", "+AAAA7"),
    ("cff'", "cff''", "+P8"),
    ("cff'", "ctqf''", "+P+8"),
    ("cff'", "cf''", "+A8"),
    ("cff'", "cqf''", "+A+8"),
    ("cff'", "c''", "+AA8"),
    ("cff'", "cqs''", "+AA+8"),
    ("cff'", "cs''", "+AAA8"),
    ("cff'", "ctqs''", "+AAA+8"),
    ("cff'", "css''", "+AAAA8"),
    ("ctqf'", "cff", "-P+8"),
    ("ctqf'", "ctqf", "-P8"),
    ("ctqf'", "cf", "-d+8"),
    ("ctqf'", "cqf", "-d8"),
    ("ctqf'", "c", "-dd+8"),
    ("ctqf'", "cqs", "-dd8"),
    ("ctqf'", "cs", "-ddd+8"),
    ("ctqf'", "ctqs", "-ddd8"),
    ("ctqf'", "css", "-dddd+8"),
    ("ctqf'", "dff", "-m+7"),
    ("ctqf'", "dtqf", "-m7"),
    ("ctqf'", "df", "-d+7"),
    ("ctqf'", "dqf", "-d7"),
    ("ctqf'", "d", "-dd+7"),
    ("ctqf'", "dqs", "-dd7"),
    ("ctqf'", "ds", "-ddd+7"),
    ("ctqf'", "dtqs", "-ddd7"),
    ("ctqf'", "dss", "-dddd+7"),
    ("ctqf'", "eff", "-m+6"),
    ("ctqf'", "etqf", "-m6"),
    ("ctqf'", "ef", "-d+6"),
    ("ctqf'", "eqf", "-d6"),
    ("ctqf'", "e", "-dd+6"),
    ("ctqf'", "eqs", "-dd6"),
    ("ctqf'", "es", "-ddd+6"),
    ("ctqf'", "etqs", "-ddd6"),
    ("ctqf'", "ess", "-dddd+6"),
    ("ctqf'", "fff", "-P+5"),
    ("ctqf'", "ftqf", "-P5"),
    ("ctqf'", "ff", "-d+5"),
    ("ctqf'", "fqf", "-d5"),
    ("ctqf'", "f", "-dd+5"),
    ("ctqf'", "fqs", "-dd5"),
    ("ctqf'", "fs", "-ddd+5"),
    ("ctqf'", "ftqs", "-ddd5"),
    ("ctqf'", "fss", "-dddd+5"),
    ("ctqf'", "gff", "-P+4"),
    ("ctqf'", "gtqf", "-P4"),
    ("ctqf'", "gf", "-d+4"),
    ("ctqf'", "gqf", "-d4"),
    ("ctqf'", "g", "-dd+4"),
    ("ctqf'", "gqs", "-dd4"),
    ("ctqf'", "gs", "-ddd+4"),
    ("ctqf'", "gtqs", "-ddd4"),
    ("ctqf'", "gss", "-dddd+4"),
    ("ctqf'", "aff", "-m+3"),
    ("ctqf'", "atqf", "-m3"),
    ("ctqf'", "af", "-d+3"),
    ("ctqf'", "aqf", "-d3"),
    ("ctqf'", "a", "-dd+3"),
    ("ctqf'", "aqs", "-dd3"),
    ("ctqf'", "as", "-ddd+3"),
    ("ctqf'", "atqs", "-ddd3"),
    ("ctqf'", "ass", "-dddd+3"),
    ("ctqf'", "bff", "-m+2"),
    ("ctqf'", "btqf", "-m2"),
    ("ctqf'", "bf", "-d+2"),
    ("ctqf'", "bqf", "-d2"),
    ("ctqf'", "b", "-dd+2"),
    ("ctqf'", "bqs", "-dd2"),
    ("ctqf'", "bs", "-ddd+2"),
    ("ctqf'", "btqs", "-ddd2"),
    ("ctqf'", "bss", "-dddd+2"),
    ("ctqf'", "cff'", "-P+1"),
    ("ctqf'", "ctqf'", "P1"),
    ("ctqf'", "cf'", "+P+1"),
    ("ctqf'", "cqf'", "+A1"),
    ("ctqf'", "c'", "+A+1"),
    ("ctqf'", "cqs'", "+AA1"),
    ("ctqf'", "cs'", "+AA+1"),
    ("ctqf'", "ctqs'", "+AAA1"),
    ("ctqf'", "css'", "+AAA+1"),
    ("ctqf'", "dff'", "+m+2"),
    ("ctqf'", "dtqf'", "+M2"),
    ("ctqf'", "df'", "+M+2"),
    ("ctqf'", "dqf'", "+A2"),
    ("ctqf'", "d'", "+A+2"),
    ("ctqf'", "dqs'", "+AA2"),
    ("ctqf'", "ds'", "+AA+2"),
    ("ctqf'", "dtqs'", "+AAA2"),
    ("ctqf'", "dss'", "+AAA+2"),
    ("ctqf'", "eff'", "+m+3"),
    ("ctqf'", "etqf'", "+M3"),
    ("ctqf'", "ef'", "+M+3"),
    ("ctqf'", "eqf'", "+A3"),
    ("ctqf'", "e'", "+A+3"),
    ("ctqf'", "eqs'", "+AA3"),
    ("ctqf'", "es'", "+AA+3"),
    ("ctqf'", "etqs'", "+AAA3"),
    ("ctqf'", "ess'", "+AAA+3"),
    ("ctqf'", "fff'", "+d+4"),
    ("ctqf'", "ftqf'", "+P4"),
    ("ctqf'", "ff'", "+P+4"),
    ("ctqf'", "fqf'", "+A4"),
    ("ctqf'", "f'", "+A+4"),
    ("ctqf'", "fqs'", "+AA4"),
    ("ctqf'", "fs'", "+AA+4"),
    ("ctqf'", "ftqs'", "+AAA4"),
    ("ctqf'", "fss'", "+AAA+4"),
    ("ctqf'", "gff'", "+d+5"),
    ("ctqf'", "gtqf'", "+P5"),
    ("ctqf'", "gf'", "+P+5"),
    ("ctqf'", "gqf'", "+A5"),
    ("ctqf'", "g'", "+A+5"),
    ("ctqf'", "gqs'", "+AA5"),
    ("ctqf'", "gs'", "+AA+5"),
    ("ctqf'", "gtqs'", "+AAA5"),
    ("ctqf'", "gss'", "+AAA+5"),
    ("ctqf'", "aff'", "+m+6"),
    ("ctqf'", "atqf'", "+M6"),
    ("ctqf'", "af'", "+M+6"),
    ("ctqf'", "aqf'", "+A6"),
    ("ctqf'", "a'", "+A+6"),
    ("ctqf'", "aqs'", "+AA6"),
    ("ctqf'", "as'", "+AA+6"),
    ("ctqf'", "atqs'", "+AAA6"),
    ("ctqf'", "ass'", "+AAA+6"),
    ("ctqf'", "bff'", "+m+7"),
    ("ctqf'", "btqf'", "+M7"),
    ("ctqf'", "bf'", "+M+7"),
    ("ctqf'", "bqf'", "+A7"),
    ("ctqf'", "b'", "+A+7"),
    ("ctqf'", "bqs'", "+AA7"),
    ("ctqf'", "bs'", "+AA+7"),
    ("ctqf'", "btqs'", "+AAA7"),
    ("ctqf'", "bss'", "+AAA+7"),
    ("ctqf'", "cff''", "+d+8"),
    ("ctqf'", "ctqf''", "+P8"),
    ("ctqf'", "cf''", "+P+8"),
    ("ctqf'", "cqf''", "+A8"),
    ("ctqf'", "c''", "+A+8"),
    ("ctqf'", "cqs''", "+AA8"),
    ("ctqf'", "cs''", "+AA+8"),
    ("ctqf'", "ctqs''", "+AAA8"),
    ("ctqf'", "css''", "+AAA+8"),
    ("cf'", "cff", "-A8"),
    ("cf'", "ctqf", "-P+8"),
    ("cf'", "cf", "-P8"),
    ("cf'", "cqf", "-d+8"),
    ("cf'", "c", "-d8"),
    ("cf'", "cqs", "-dd+8"),
    ("cf'", "cs", "-dd8"),
    ("cf'", "ctqs", "-ddd+8"),
    ("cf'", "css", "-ddd8"),
    ("cf'", "dff", "-M7"),
    ("cf'", "dtqf", "-m+7"),
    ("cf'", "df", "-m7"),
    ("cf'", "dqf", "-d+7"),
    ("cf'", "d", "-d7"),
    ("cf'", "dqs", "-dd+7"),
    ("cf'", "ds", "-dd7"),
    ("cf'", "dtqs", "-ddd+7"),
    ("cf'", "dss", "-ddd7"),
    ("cf'", "eff", "-M6"),
    ("cf'", "etqf", "-m+6"),
    ("cf'", "ef", "-m6"),
    ("cf'", "eqf", "-d+6"),
    ("cf'", "e", "-d6"),
    ("cf'", "eqs", "-dd+6"),
    ("cf'", "es", "-dd6"),
    ("cf'", "etqs", "-ddd+6"),
    ("cf'", "ess", "-ddd6"),
    ("cf'", "fff", "-A5"),
    ("cf'", "ftqf", "-P+5"),
    ("cf'", "ff", "-P5"),
    ("cf'", "fqf", "-d+5"),
    ("cf'", "f", "-d5"),
    ("cf'", "fqs", "-dd+5"),
    ("cf'", "fs", "-dd5"),
    ("cf'", "ftqs", "-ddd+5"),
    ("cf'", "fss", "-ddd5"),
    ("cf'", "gff", "-A4"),
    ("cf'", "gtqf", "-P+4"),
    ("cf'", "gf", "-P4"),
    ("cf'", "gqf", "-d+4"),
    ("cf'", "g", "-d4"),
    ("cf'", "gqs", "-dd+4"),
    ("cf'", "gs", "-dd4"),
    ("cf'", "gtqs", "-ddd+4"),
    ("cf'", "gss", "-ddd4"),
    ("cf'", "aff", "-M3"),
    ("cf'", "atqf", "-m+3"),
    ("cf'", "af", "-m3"),
    ("cf'", "aqf", "-d+3"),
    ("cf'", "a", "-d3"),
    ("cf'", "aqs", "-dd+3"),
    ("cf'", "as", "-dd3"),
    ("cf'", "atqs", "-ddd+3"),
    ("cf'", "ass", "-ddd3"),
    ("cf'", "bff", "-M2"),
    ("cf'", "btqf", "-m+2"),
    ("cf'", "bf", "-m2"),
    ("cf'", "bqf", "-d+2"),
    ("cf'", "b", "-d2"),
    ("cf'", "bqs", "-dd+2"),
    ("cf'", "bs", "-dd2"),
    ("cf'", "btqs", "-ddd+2"),
    ("cf'", "bss", "-ddd2"),
    ("cf'", "cff'", "-A1"),
    ("cf'", "ctqf'", "-P+1"),
    ("cf'", "cf'", "P1"),
    ("cf'", "cqf'", "+P+1"),
    ("cf'", "c'", "+A1"),
    ("cf'", "cqs'", "+A+1"),
    ("cf'", "cs'", "+AA1"),
    ("cf'", "ctqs'", "+AA+1"),
    ("cf'", "css'", "+AAA1"),
    ("cf'", "dff'", "+m2"),
    ("cf'", "dtqf'", "+m+2"),
    ("cf'", "df'", "+M2"),
    ("cf'", "dqf'", "+M+2"),
    ("cf'", "d'", "+A2"),
    ("cf'", "dqs'", "+A+2"),
    ("cf'", "ds'", "+AA2"),
    ("cf'", "dtqs'", "+AA+2"),
    ("cf'", "dss'", "+AAA2"),
    ("cf'", "eff'", "+m3"),
    ("cf'", "etqf'", "+m+3"),
    ("cf'", "ef'", "+M3"),
    ("cf'", "eqf'", "+M+3"),
    ("cf'", "e'", "+A3"),
    ("cf'", "eqs'", "+A+3"),
    ("cf'", "es'", "+AA3"),
    ("cf'", "etqs'", "+AA+3"),
    ("cf'", "ess'", "+AAA3"),
    ("cf'", "fff'", "+d4"),
    ("cf'", "ftqf'", "+d+4"),
    ("cf'", "ff'", "+P4"),
    ("cf'", "fqf'", "+P+4"),
    ("cf'", "f'", "+A4"),
    ("cf'", "fqs'", "+A+4"),
    ("cf'", "fs'", "+AA4"),
    ("cf'", "ftqs'", "+AA+4"),
    ("cf'", "fss'", "+AAA4"),
    ("cf'", "gff'", "+d5"),
    ("cf'", "gtqf'", "+d+5"),
    ("cf'", "gf'", "+P5"),
    ("cf'", "gqf'", "+P+5"),
    ("cf'", "g'", "+A5"),
    ("cf'", "gqs'", "+A+5"),
    ("cf'", "gs'", "+AA5"),
    ("cf'", "gtqs'", "+AA+5"),
    ("cf'", "gss'", "+AAA5"),
    ("cf'", "aff'", "+m6"),
    ("cf'", "atqf'", "+m+6"),
    ("cf'", "af'", "+M6"),
    ("cf'", "aqf'", "+M+6"),
    ("cf'", "a'", "+A6"),
    ("cf'", "aqs'", "+A+6"),
    ("cf'", "as'", "+AA6"),
    ("cf'", "atqs'", "+AA+6"),
    ("cf'", "ass'", "+AAA6"),
    ("cf'", "bff'", "+m7"),
    ("cf'", "btqf'", "+m+7"),
    ("cf'", "bf'", "+M7"),
    ("cf'", "bqf'", "+M+7"),
    ("cf'", "b'", "+A7"),
    ("cf'", "bqs'", "+A+7"),
    ("cf'", "bs'", "+AA7"),
    ("cf'", "btqs'", "+AA+7"),
    ("cf'", "bss'", "+AAA7"),
    ("cf'", "cff''", "+d8"),
    ("cf'", "ctqf''", "+d+8"),
    ("cf'", "cf''", "+P8"),
    ("cf'", "cqf''", "+P+8"),
    ("cf'", "c''", "+A8"),
    ("cf'", "cqs''", "+A+8"),
    ("cf'", "cs''", "+AA8"),
    ("cf'", "ctqs''", "+AA+8"),
    ("cf'", "css''", "+AAA8"),
    ("cqf'", "cff", "-A+8"),
    ("cqf'", "ctqf", "-A8"),
    ("cqf'", "cf", "-P+8"),
    ("cqf'", "cqf", "-P8"),
    ("cqf'", "c", "-d+8"),
    ("cqf'", "cqs", "-d8"),
    ("cqf'", "cs", "-dd+8"),
    ("cqf'", "ctqs", "-dd8"),
    ("cqf'", "css", "-ddd+8"),
    ("cqf'", "dff", "-M+7"),
    ("cqf'", "dtqf", "-M7"),
    ("cqf'", "df", "-m+7"),
    ("cqf'", "dqf", "-m7"),
    ("cqf'", "d", "-d+7"),
    ("cqf'", "dqs", "-d7"),
    ("cqf'", "ds", "-dd+7"),
    ("cqf'", "dtqs", "-dd7"),
    ("cqf'", "dss", "-ddd+7"),
    ("cqf'", "eff", "-M+6"),
    ("cqf'", "etqf", "-M6"),
    ("cqf'", "ef", "-m+6"),
    ("cqf'", "eqf", "-m6"),
    ("cqf'", "e", "-d+6"),
    ("cqf'", "eqs", "-d6"),
    ("cqf'", "es", "-dd+6"),
    ("cqf'", "etqs", "-dd6"),
    ("cqf'", "ess", "-ddd+6"),
    ("cqf'", "fff", "-A+5"),
    ("cqf'", "ftqf", "-A5"),
    ("cqf'", "ff", "-P+5"),
    ("cqf'", "fqf", "-P5"),
    ("cqf'", "f", "-d+5"),
    ("cqf'", "fqs", "-d5"),
    ("cqf'", "fs", "-dd+5"),
    ("cqf'", "ftqs", "-dd5"),
    ("cqf'", "fss", "-ddd+5"),
    ("cqf'", "gff", "-A+4"),
    ("cqf'", "gtqf", "-A4"),
    ("cqf'", "gf", "-P+4"),
    ("cqf'", "gqf", "-P4"),
    ("cqf'", "g", "-d+4"),
    ("cqf'", "gqs", "-d4"),
    ("cqf'", "gs", "-dd+4"),
    ("cqf'", "gtqs", "-dd4"),
    ("cqf'", "gss", "-ddd+4"),
    ("cqf'", "aff", "-M+3"),
    ("cqf'", "atqf", "-M3"),
    ("cqf'", "af", "-m+3"),
    ("cqf'", "aqf", "-m3"),
    ("cqf'", "a", "-d+3"),
    ("cqf'", "aqs", "-d3"),
    ("cqf'", "as", "-dd+3"),
    ("cqf'", "atqs", "-dd3"),
    ("cqf'", "ass", "-ddd+3"),
    ("cqf'", "bff", "-M+2"),
    ("cqf'", "btqf", "-M2"),
    ("cqf'", "bf", "-m+2"),
    ("cqf'", "bqf", "-m2"),
    ("cqf'", "b", "-d+2"),
    ("cqf'", "bqs", "-d2"),
    ("cqf'", "bs", "-dd+2"),
    ("cqf'", "btqs", "-dd2"),
    ("cqf'", "bss", "-ddd+2"),
    ("cqf'", "cff'", "-A+1"),
    ("cqf'", "ctqf'", "-A1"),
    ("cqf'", "cf'", "-P+1"),
    ("cqf'", "cqf'", "P1"),
    ("cqf'", "c'", "+P+1"),
    ("cqf'", "cqs'", "+A1"),
    ("cqf'", "cs'", "+A+1"),
    ("cqf'", "ctqs'", "+AA1"),
    ("cqf'", "css'", "+AA+1"),
    ("cqf'", "dff'", "+d+2"),
    ("cqf'", "dtqf'", "+m2"),
    ("cqf'", "df'", "+m+2"),
    ("cqf'", "dqf'", "+M2"),
    ("cqf'", "d'", "+M+2"),
    ("cqf'", "dqs'", "+A2"),
    ("cqf'", "ds'", "+A+2"),
    ("cqf'", "dtqs'", "+AA2"),
    ("cqf'", "dss'", "+AA+2"),
    ("cqf'", "eff'", "+d+3"),
    ("cqf'", "etqf'", "+m3"),
    ("cqf'", "ef'", "+m+3"),
    ("cqf'", "eqf'", "+M3"),
    ("cqf'", "e'", "+M+3"),
    ("cqf'", "eqs'", "+A3"),
    ("cqf'", "es'", "+A+3"),
    ("cqf'", "etqs'", "+AA3"),
    ("cqf'", "ess'", "+AA+3"),
    ("cqf'", "fff'", "+dd+4"),
    ("cqf'", "ftqf'", "+d4"),
    ("cqf'", "ff'", "+d+4"),
    ("cqf'", "fqf'", "+P4"),
    ("cqf'", "f'", "+P+4"),
    ("cqf'", "fqs'", "+A4"),
    ("cqf'", "fs'", "+A+4"),
    ("cqf'", "ftqs'", "+AA4"),
    ("cqf'", "fss'", "+AA+4"),
    ("cqf'", "gff'", "+dd+5"),
    ("cqf'", "gtqf'", "+d5"),
    ("cqf'", "gf'", "+d+5"),
    ("cqf'", "gqf'", "+P5"),
    ("cqf'", "g'", "+P+5"),
    ("cqf'", "gqs'", "+A5"),
    ("cqf'", "gs'", "+A+5"),
    ("cqf'", "gtqs'", "+AA5"),
    ("cqf'", "gss'", "+AA+5"),
    ("cqf'", "aff'", "+d+6"),
    ("cqf'", "atqf'", "+m6"),
    ("cqf'", "af'", "+m+6"),
    ("cqf'", "aqf'", "+M6"),
    ("cqf'", "a'", "+M+6"),
    ("cqf'", "aqs'", "+A6"),
    ("cqf'", "as'", "+A+6"),
    ("cqf'", "atqs'", "+AA6"),
    ("cqf'", "ass'", "+AA+6"),
    ("cqf'", "bff'", "+d+7"),
    ("cqf'", "btqf'", "+m7"),
    ("cqf'", "bf'", "+m+7"),
    ("cqf'", "bqf'", "+M7"),
    ("cqf'", "b'", "+M+7"),
    ("cqf'", "bqs'", "+A7"),
    ("cqf'", "bs'", "+A+7"),
    ("cqf'", "btqs'", "+AA7"),
    ("cqf'", "bss'", "+AA+7"),
    ("cqf'", "cff''", "+dd+8"),
    ("cqf'", "ctqf''", "+d8"),
    ("cqf'", "cf''", "+d+8"),
    ("cqf'", "cqf''", "+P8"),
    ("cqf'", "c''", "+P+8"),
    ("cqf'", "cqs''", "+A8"),
    ("cqf'", "cs''", "+A+8"),
    ("cqf'", "ctqs''", "+AA8"),
    ("cqf'", "css''", "+AA+8"),
    ("c'", "cff", "-AA8"),
    ("c'", "ctqf", "-A+8"),
    ("c'", "cf", "-A8"),
    ("c'", "cqf", "-P+8"),
    ("c'", "c", "-P8"),
    ("c'", "cqs", "-d+8"),
    ("c'", "cs", "-d8"),
    ("c'", "ctqs", "-dd+8"),
    ("c'", "css", "-dd8"),
    ("c'", "dff", "-A7"),
    ("c'", "dtqf", "-M+7"),
    ("c'", "df", "-M7"),
    ("c'", "dqf", "-m+7"),
    ("c'", "d", "-m7"),
    ("c'", "dqs", "-d+7"),
    ("c'", "ds", "-d7"),
    ("c'", "dtqs", "-dd+7"),
    ("c'", "dss", "-dd7"),
    ("c'", "eff", "-A6"),
    ("c'", "etqf", "-M+6"),
    ("c'", "ef", "-M6"),
    ("c'", "eqf", "-m+6"),
    ("c'", "e", "-m6"),
    ("c'", "eqs", "-d+6"),
    ("c'", "es", "-d6"),
    ("c'", "etqs", "-dd+6"),
    ("c'", "ess", "-dd6"),
    ("c'", "fff", "-AA5"),
    ("c'", "ftqf", "-A+5"),
    ("c'", "ff", "-A5"),
    ("c'", "fqf", "-P+5"),
    ("c'", "f", "-P5"),
    ("c'", "fqs", "-d+5"),
    ("c'", "fs", "-d5"),
    ("c'", "ftqs", "-dd+5"),
    ("c'", "fss", "-dd5"),
    ("c'", "gff", "-AA4"),
    ("c'", "gtqf", "-A+4"),
    ("c'", "gf", "-A4"),
    ("c'", "gqf", "-P+4"),
    ("c'", "g", "-P4"),
    ("c'", "gqs", "-d+4"),
    ("c'", "gs", "-d4"),
    ("c'", "gtqs", "-dd+4"),
    ("c'", "gss", "-dd4"),
    ("c'", "aff", "-A3"),
    ("c'", "atqf", "-M+3"),
    ("c'", "af", "-M3"),
    ("c'", "aqf", "-m+3"),
    ("c'", "a", "-m3"),
    ("c'", "aqs", "-d+3"),
    ("c'", "as", "-d3"),
    ("c'", "atqs", "-dd+3"),
    ("c'", "ass", "-dd3"),
    ("c'", "bff", "-A2"),
    ("c'", "btqf", "-M+2"),
    ("c'", "bf", "-M2"),
    ("c'", "bqf", "-m+2"),
    ("c'", "b", "-m2"),
    ("c'", "bqs", "-d+2"),
    ("c'", "bs", "-d2"),
    ("c'", "btqs", "-dd+2"),
    ("c'", "bss", "-dd2"),
    ("c'", "cff'", "-AA1"),
    ("c'", "ctqf'", "-A+1"),
    ("c'", "cf'", "-A1"),
    ("c'", "cqf'", "-P+1"),
    ("c'", "c'", "P1"),
    ("c'", "cqs'", "+P+1"),
    ("c'", "cs'", "+A1"),
    ("c'", "ctqs'", "+A+1"),
    ("c'", "css'", "+AA1"),
    ("c'", "dff'", "+d2"),
    ("c'", "dtqf'", "+d+2"),
    ("c'", "df'", "+m2"),
    ("c'", "dqf'", "+m+2"),
    ("c'", "d'", "+M2"),
    ("c'", "dqs'", "+M+2"),
    ("c'", "ds'", "+A2"),
    ("c'", "dtqs'", "+A+2"),
    ("c'", "dss'", "+AA2"),
    ("c'", "eff'", "+d3"),
    ("c'", "etqf'", "+d+3"),
    ("c'", "ef'", "+m3"),
    ("c'", "eqf'", "+m+3"),
    ("c'", "e'", "+M3"),
    ("c'", "eqs'", "+M+3"),
    ("c'", "es'", "+A3"),
    ("c'", "etqs'", "+A+3"),
    ("c'", "ess'", "+AA3"),
    ("c'", "fff'", "+dd4"),
    ("c'", "ftqf'", "+dd+4"),
    ("c'", "ff'", "+d4"),
    ("c'", "fqf'", "+d+4"),
    ("c'", "f'", "+P4"),
    ("c'", "fqs'", "+P+4"),
    ("c'", "fs'", "+A4"),
    ("c'", "ftqs'", "+A+4"),
    ("c'", "fss'", "+AA4"),
    ("c'", "gff'", "+dd5"),
    ("c'", "gtqf'", "+dd+5"),
    ("c'", "gf'", "+d5"),
    ("c'", "gqf'", "+d+5"),
    ("c'", "g'", "+P5"),
    ("c'", "gqs'", "+P+5"),
    ("c'", "gs'", "+A5"),
    ("c'", "gtqs'", "+A+5"),
    ("c'", "gss'", "+AA5"),
    ("c'", "aff'", "+d6"),
    ("c'", "atqf'", "+d+6"),
    ("c'", "af'", "+m6"),
    ("c'", "aqf'", "+m+6"),
    ("c'", "a'", "+M6"),
    ("c'", "aqs'", "+M+6"),
    ("c'", "as'", "+A6"),
    ("c'", "atqs'", "+A+6"),
    ("c'", "ass'", "+AA6"),
    ("c'", "bff'", "+d7"),
    ("c'", "btqf'", "+d+7"),
    ("c'", "bf'", "+m7"),
    ("c'", "bqf'", "+m+7"),
    ("c'", "b'", "+M7"),
    ("c'", "bqs'", "+M+7"),
    ("c'", "bs'", "+A7"),
    ("c'", "btqs'", "+A+7"),
    ("c'", "bss'", "+AA7"),
    ("c'", "cff''", "+dd8"),
    ("c'", "ctqf''", "+dd+8"),
    ("c'", "cf''", "+d8"),
    ("c'", "cqf''", "+d+8"),
    ("c'", "c''", "+P8"),
    ("c'", "cqs''", "+P+8"),
    ("c'", "cs''", "+A8"),
    ("c'", "ctqs''", "+A+8"),
    ("c'", "css''", "+AA8"),
    ("cqs'", "cff", "-AA+8"),
    ("cqs'", "ctqf", "-AA8"),
    ("cqs'", "cf", "-A+8"),
    ("cqs'", "cqf", "-A8"),
    ("cqs'", "c", "-P+8"),
    ("cqs'", "cqs", "-P8"),
    ("cqs'", "cs", "-d+8"),
    ("cqs'", "ctqs", "-d8"),
    ("cqs'", "css", "-dd+8"),
    ("cqs'", "dff", "-A+7"),
    ("cqs'", "dtqf", "-A7"),
    ("cqs'", "df", "-M+7"),
    ("cqs'", "dqf", "-M7"),
    ("cqs'", "d", "-m+7"),
    ("cqs'", "dqs", "-m7"),
    ("cqs'", "ds", "-d+7"),
    ("cqs'", "dtqs", "-d7"),
    ("cqs'", "dss", "-dd+7"),
    ("cqs'", "eff", "-A+6"),
    ("cqs'", "etqf", "-A6"),
    ("cqs'", "ef", "-M+6"),
    ("cqs'", "eqf", "-M6"),
    ("cqs'", "e", "-m+6"),
    ("cqs'", "eqs", "-m6"),
    ("cqs'", "es", "-d+6"),
    ("cqs'", "etqs", "-d6"),
    ("cqs'", "ess", "-dd+6"),
    ("cqs'", "fff", "-AA+5"),
    ("cqs'", "ftqf", "-AA5"),
    ("cqs'", "ff", "-A+5"),
    ("cqs'", "fqf", "-A5"),
    ("cqs'", "f", "-P+5"),
    ("cqs'", "fqs", "-P5"),
    ("cqs'", "fs", "-d+5"),
    ("cqs'", "ftqs", "-d5"),
    ("cqs'", "fss", "-dd+5"),
    ("cqs'", "gff", "-AA+4"),
    ("cqs'", "gtqf", "-AA4"),
    ("cqs'", "gf", "-A+4"),
    ("cqs'", "gqf", "-A4"),
    ("cqs'", "g", "-P+4"),
    ("cqs'", "gqs", "-P4"),
    ("cqs'", "gs", "-d+4"),
    ("cqs'", "gtqs", "-d4"),
    ("cqs'", "gss", "-dd+4"),
    ("cqs'", "aff", "-A+3"),
    ("cqs'", "atqf", "-A3"),
    ("cqs'", "af", "-M+3"),
    ("cqs'", "aqf", "-M3"),
    ("cqs'", "a", "-m+3"),
    ("cqs'", "aqs", "-m3"),
    ("cqs'", "as", "-d+3"),
    ("cqs'", "atqs", "-d3"),
    ("cqs'", "ass", "-dd+3"),
    ("cqs'", "bff", "-A+2"),
    ("cqs'", "btqf", "-A2"),
    ("cqs'", "bf", "-M+2"),
    ("cqs'", "bqf", "-M2"),
    ("cqs'", "b", "-m+2"),
    ("cqs'", "bqs", "-m2"),
    ("cqs'", "bs", "-d+2"),
    ("cqs'", "btqs", "-d2"),
    ("cqs'", "bss", "-dd+2"),
    ("cqs'", "cff'", "-AA+1"),
    ("cqs'", "ctqf'", "-AA1"),
    ("cqs'", "cf'", "-A+1"),
    ("cqs'", "cqf'", "-A1"),
    ("cqs'", "c'", "-P+1"),
    ("cqs'", "cqs'", "P1"),
    ("cqs'", "cs'", "+P+1"),
    ("cqs'", "ctqs'", "+A1"),
    ("cqs'", "css'", "+A+1"),
    ("cqs'", "dff'", "+dd+2"),
    ("cqs'", "dtqf'", "+d2"),
    ("cqs'", "df'", "+d+2"),
    ("cqs'", "dqf'", "+m2"),
    ("cqs'", "d'", "+m+2"),
    ("cqs'", "dqs'", "+M2"),
    ("cqs'", "ds'", "+M+2"),
    ("cqs'", "dtqs'", "+A2"),
    ("cqs'", "dss'", "+A+2"),
    ("cqs'", "eff'", "+dd+3"),
    ("cqs'", "etqf'", "+d3"),
    ("cqs'", "ef'", "+d+3"),
    ("cqs'", "eqf'", "+m3"),
    ("cqs'", "e'", "+m+3"),
    ("cqs'", "eqs'", "+M3"),
    ("cqs'", "es'", "+M+3"),
    ("cqs'", "etqs'", "+A3"),
    ("cqs'", "ess'", "+A+3"),
    ("cqs'", "fff'", "+ddd+4"),
    ("cqs'", "ftqf'", "+dd4"),
    ("cqs'", "ff'", "+dd+4"),
    ("cqs'", "fqf'", "+d4"),
    ("cqs'", "f'", "+d+4"),
    ("cqs'", "fqs'", "+P4"),
    ("cqs'", "fs'", "+P+4"),
    ("cqs'", "ftqs'", "+A4"),
    ("cqs'", "fss'", "+A+4"),
    ("cqs'", "gff'", "+ddd+5"),
    ("cqs'", "gtqf'", "+dd5"),
    ("cqs'", "gf'", "+dd+5"),
    ("cqs'", "gqf'", "+d5"),
    ("cqs'", "g'", "+d+5"),
    ("cqs'", "gqs'", "+P5"),
    ("cqs'", "gs'", "+P+5"),
    ("cqs'", "gtqs'", "+A5"),
    ("cqs'", "gss'", "+A+5"),
    ("cqs'", "aff'", "+dd+6"),
    ("cqs'", "atqf'", "+d6"),
    ("cqs'", "af'", "+d+6"),
    ("cqs'", "aqf'", "+m6"),
    ("cqs'", "a'", "+m+6"),
    ("cqs'", "aqs'", "+M6"),
    ("cqs'", "as'", "+M+6"),
    ("cqs'", "atqs'", "+A6"),
    ("cqs'", "ass'", "+A+6"),
    ("cqs'", "bff'", "+dd+7"),
    ("cqs'", "btqf'", "+d7"),
    ("cqs'", "bf'", "+d+7"),
    ("cqs'", "bqf'", "+m7"),
    ("cqs'", "b'", "+m+7"),
    ("cqs'", "bqs'", "+M7"),
    ("cqs'", "bs'", "+M+7"),
    ("cqs'", "btqs'", "+A7"),
    ("cqs'", "bss'", "+A+7"),
    ("cqs'", "cff''", "+ddd+8"),
    ("cqs'", "ctqf''", "+dd8"),
    ("cqs'", "cf''", "+dd+8"),
    ("cqs'", "cqf''", "+d8"),
    ("cqs'", "c''", "+d+8"),
    ("cqs'", "cqs''", "+P8"),
    ("cqs'", "cs''", "+P+8"),
    ("cqs'", "ctqs''", "+A8"),
    ("cqs'", "css''", "+A+8"),
    ("cs'", "cff", "-AAA8"),
    ("cs'", "ctqf", "-AA+8"),
    ("cs'", "cf", "-AA8"),
    ("cs'", "cqf", "-A+8"),
    ("cs'", "c", "-A8"),
    ("cs'", "cqs", "-P+8"),
    ("cs'", "cs", "-P8"),
    ("cs'", "ctqs", "-d+8"),
    ("cs'", "css", "-d8"),
    ("cs'", "dff", "-AA7"),
    ("cs'", "dtqf", "-A+7"),
    ("cs'", "df", "-A7"),
    ("cs'", "dqf", "-M+7"),
    ("cs'", "d", "-M7"),
    ("cs'", "dqs", "-m+7"),
    ("cs'", "ds", "-m7"),
    ("cs'", "dtqs", "-d+7"),
    ("cs'", "dss", "-d7"),
    ("cs'", "eff", "-AA6"),
    ("cs'", "etqf", "-A+6"),
    ("cs'", "ef", "-A6"),
    ("cs'", "eqf", "-M+6"),
    ("cs'", "e", "-M6"),
    ("cs'", "eqs", "-m+6"),
    ("cs'", "es", "-m6"),
    ("cs'", "etqs", "-d+6"),
    ("cs'", "ess", "-d6"),
    ("cs'", "fff", "-AAA5"),
    ("cs'", "ftqf", "-AA+5"),
    ("cs'", "ff", "-AA5"),
    ("cs'", "fqf", "-A+5"),
    ("cs'", "f", "-A5"),
    ("cs'", "fqs", "-P+5"),
    ("cs'", "fs", "-P5"),
    ("cs'", "ftqs", "-d+5"),
    ("cs'", "fss", "-d5"),
    ("cs'", "gff", "-AAA4"),
    ("cs'", "gtqf", "-AA+4"),
    ("cs'", "gf", "-AA4"),
    ("cs'", "gqf", "-A+4"),
    ("cs'", "g", "-A4"),
    ("cs'", "gqs", "-P+4"),
    ("cs'", "gs", "-P4"),
    ("cs'", "gtqs", "-d+4"),
    ("cs'", "gss", "-d4"),
    ("cs'", "aff", "-AA3"),
    ("cs'", "atqf", "-A+3"),
    ("cs'", "af", "-A3"),
    ("cs'", "aqf", "-M+3"),
    ("cs'", "a", "-M3"),
    ("cs'", "aqs", "-m+3"),
    ("cs'", "as", "-m3"),
    ("cs'", "atqs", "-d+3"),
    ("cs'", "ass", "-d3"),
    ("cs'", "bff", "-AA2"),
    ("cs'", "btqf", "-A+2"),
    ("cs'", "bf", "-A2"),
    ("cs'", "bqf", "-M+2"),
    ("cs'", "b", "-M2"),
    ("cs'", "bqs", "-m+2"),
    ("cs'", "bs", "-m2"),
    ("cs'", "btqs", "-d+2"),
    ("cs'", "bss", "-d2"),
    ("cs'", "cff'", "-AAA1"),
    ("cs'", "ctqf'", "-AA+1"),
    ("cs'", "cf'", "-AA1"),
    ("cs'", "cqf'", "-A+1"),
    ("cs'", "c'", "-A1"),
    ("cs'", "cqs'", "-P+1"),
    ("cs'", "cs'", "P1"),
    ("cs'", "ctqs'", "+P+1"),
    ("cs'", "css'", "+A1"),
    ("cs'", "dff'", "+dd2"),
    ("cs'", "dtqf'", "+dd+2"),
    ("cs'", "df'", "+d2"),
    ("cs'", "dqf'", "+d+2"),
    ("cs'", "d'", "+m2"),
    ("cs'", "dqs'", "+m+2"),
    ("cs'", "ds'", "+M2"),
    ("cs'", "dtqs'", "+M+2"),
    ("cs'", "dss'", "+A2"),
    ("cs'", "eff'", "+dd3"),
    ("cs'", "etqf'", "+dd+3"),
    ("cs'", "ef'", "+d3"),
    ("cs'", "eqf'", "+d+3"),
    ("cs'", "e'", "+m3"),
    ("cs'", "eqs'", "+m+3"),
    ("cs'", "es'", "+M3"),
    ("cs'", "etqs'", "+M+3"),
    ("cs'", "ess'", "+A3"),
    ("cs'", "fff'", "+ddd4"),
    ("cs'", "ftqf'", "+ddd+4"),
    ("cs'", "ff'", "+dd4"),
    ("cs'", "fqf'", "+dd+4"),
    ("cs'", "f'", "+d4"),
    ("cs'", "fqs'", "+d+4"),
    ("cs'", "fs'", "+P4"),
    ("cs'", "ftqs'", "+P+4"),
    ("cs'", "fss'", "+A4"),
    ("cs'", "gff'", "+ddd5"),
    ("cs'", "gtqf'", "+ddd+5"),
    ("cs'", "gf'", "+dd5"),
    ("cs'", "gqf'", "+dd+5"),
    ("cs'", "g'", "+d5"),
    ("cs'", "gqs'", "+d+5"),
    ("cs'", "gs'", "+P5"),
    ("cs'", "gtqs'", "+P+5"),
    ("cs'", "gss'", "+A5"),
    ("cs'", "aff'", "+dd6"),
    ("cs'", "atqf'", "+dd+6"),
    ("cs'", "af'", "+d6"),
    ("cs'", "aqf'", "+d+6"),
    ("cs'", "a'", "+m6"),
    ("cs'", "aqs'", "+m+6"),
    ("cs'", "as'", "+M6"),
    ("cs'", "atqs'", "+M+6"),
    ("cs'", "ass'", "+A6"),
    ("cs'", "bff'", "+dd7"),
    ("cs'", "btqf'", "+dd+7"),
    ("cs'", "bf'", "+d7"),
    ("cs'", "bqf'", "+d+7"),
    ("cs'", "b'", "+m7"),
    ("cs'", "bqs'", "+m+7"),
    ("cs'", "bs'", "+M7"),
    ("cs'", "btqs'", "+M+7"),
    ("cs'", "bss'", "+A7"),
    ("cs'", "cff''", "+ddd8"),
    ("cs'", "ctqf''", "+ddd+8"),
    ("cs'", "cf''", "+dd8"),
    ("cs'", "cqf''", "+dd+8"),
    ("cs'", "c''", "+d8"),
    ("cs'", "cqs''", "+d+8"),
    ("cs'", "cs''", "+P8"),
    ("cs'", "ctqs''", "+P+8"),
    ("cs'", "css''", "+A8"),
    ("ctqs'", "cff", "-AAA+8"),
    ("ctqs'", "ctqf", "-AAA8"),
    ("ctqs'", "cf", "-AA+8"),
    ("ctqs'", "cqf", "-AA8"),
    ("ctqs'", "c", "-A+8"),
    ("ctqs'", "cqs", "-A8"),
    ("ctqs'", "cs", "-P+8"),
    ("ctqs'", "ctqs", "-P8"),
    ("ctqs'", "css", "-d+8"),
    ("ctqs'", "dff", "-AA+7"),
    ("ctqs'", "dtqf", "-AA7"),
    ("ctqs'", "df", "-A+7"),
    ("ctqs'", "dqf", "-A7"),
    ("ctqs'", "d", "-M+7"),
    ("ctqs'", "dqs", "-M7"),
    ("ctqs'", "ds", "-m+7"),
    ("ctqs'", "dtqs", "-m7"),
    ("ctqs'", "dss", "-d+7"),
    ("ctqs'", "eff", "-AA+6"),
    ("ctqs'", "etqf", "-AA6"),
    ("ctqs'", "ef", "-A+6"),
    ("ctqs'", "eqf", "-A6"),
    ("ctqs'", "e", "-M+6"),
    ("ctqs'", "eqs", "-M6"),
    ("ctqs'", "es", "-m+6"),
    ("ctqs'", "etqs", "-m6"),
    ("ctqs'", "ess", "-d+6"),
    ("ctqs'", "fff", "-AAA+5"),
    ("ctqs'", "ftqf", "-AAA5"),
    ("ctqs'", "ff", "-AA+5"),
    ("ctqs'", "fqf", "-AA5"),
    ("ctqs'", "f", "-A+5"),
    ("ctqs'", "fqs", "-A5"),
    ("ctqs'", "fs", "-P+5"),
    ("ctqs'", "ftqs", "-P5"),
    ("ctqs'", "fss", "-d+5"),
    ("ctqs'", "gff", "-AAA+4"),
    ("ctqs'", "gtqf", "-AAA4"),
    ("ctqs'", "gf", "-AA+4"),
    ("ctqs'", "gqf", "-AA4"),
    ("ctqs'", "g", "-A+4"),
    ("ctqs'", "gqs", "-A4"),
    ("ctqs'", "gs", "-P+4"),
    ("ctqs'", "gtqs", "-P4"),
    ("ctqs'", "gss", "-d+4"),
    ("ctqs'", "aff", "-AA+3"),
    ("ctqs'", "atqf", "-AA3"),
    ("ctqs'", "af", "-A+3"),
    ("ctqs'", "aqf", "-A3"),
    ("ctqs'", "a", "-M+3"),
    ("ctqs'", "aqs", "-M3"),
    ("ctqs'", "as", "-m+3"),
    ("ctqs'", "atqs", "-m3"),
    ("ctqs'", "ass", "-d+3"),
    ("ctqs'", "bff", "-AA+2"),
    ("ctqs'", "btqf", "-AA2"),
    ("ctqs'", "bf", "-A+2"),
    ("ctqs'", "bqf", "-A2"),
    ("ctqs'", "b", "-M+2"),
    ("ctqs'", "bqs", "-M2"),
    ("ctqs'", "bs", "-m+2"),
    ("ctqs'", "btqs", "-m2"),
    ("ctqs'", "bss", "-d+2"),
    ("ctqs'", "cff'", "-AAA+1"),
    ("ctqs'", "ctqf'", "-AAA1"),
    ("ctqs'", "cf'", "-AA+1"),
    ("ctqs'", "cqf'", "-AA1"),
    ("ctqs'", "c'", "-A+1"),
    ("ctqs'", "cqs'", "-A1"),
    ("ctqs'", "cs'", "-P+1"),
    ("ctqs'", "ctqs'", "P1"),
    ("ctqs'", "css'", "+P+1"),
    ("ctqs'", "dff'", "+ddd+2"),
    ("ctqs'", "dtqf'", "+dd2"),
    ("ctqs'", "df'", "+dd+2"),
    ("ctqs'", "dqf'", "+d2"),
    ("ctqs'", "d'", "+d+2"),
    ("ctqs'", "dqs'", "+m2"),
    ("ctqs'", "ds'", "+m+2"),
    ("ctqs'", "dtqs'", "+M2"),
    ("ctqs'", "dss'", "+M+2"),
    ("ctqs'", "eff'", "+ddd+3"),
    ("ctqs'", "etqf'", "+dd3"),
    ("ctqs'", "ef'", "+dd+3"),
    ("ctqs'", "eqf'", "+d3"),
    ("ctqs'", "e'", "+d+3"),
    ("ctqs'", "eqs'", "+m3"),
    ("ctqs'", "es'", "+m+3"),
    ("ctqs'", "etqs'", "+M3"),
    ("ctqs'", "ess'", "+M+3"),
    ("ctqs'", "fff'", "+dddd+4"),
    ("ctqs'", "ftqf'", "+ddd4"),
    ("ctqs'", "ff'", "+ddd+4"),
    ("ctqs'", "fqf'", "+dd4"),
    ("ctqs'", "f'", "+dd+4"),
    ("ctqs'", "fqs'", "+d4"),
    ("ctqs'", "fs'", "+d+4"),
    ("ctqs'", "ftqs'", "+P4"),
    ("ctqs'", "fss'", "+P+4"),
    ("ctqs'", "gff'", "+dddd+5"),
    ("ctqs'", "gtqf'", "+ddd5"),
    ("ctqs'", "gf'", "+ddd+5"),
    ("ctqs'", "gqf'", "+dd5"),
    ("ctqs'", "g'", "+dd+5"),
    ("ctqs'", "gqs'", "+d5"),
    ("ctqs'", "gs'", "+d+5"),
    ("ctqs'", "gtqs'", "+P5"),
    ("ctqs'", "gss'", "+P+5"),
    ("ctqs'", "aff'", "+ddd+6"),
    ("ctqs'", "atqf'", "+dd6"),
    ("ctqs'", "af'", "+dd+6"),
    ("ctqs'", "aqf'", "+d6"),
    ("ctqs'", "a'", "+d+6"),
    ("ctqs'", "aqs'", "+m6"),
    ("ctqs'", "as'", "+m+6"),
    ("ctqs'", "atqs'", "+M6"),
    ("ctqs'", "ass'", "+M+6"),
    ("ctqs'", "bff'", "+ddd+7"),
    ("ctqs'", "btqf'", "+dd7"),
    ("ctqs'", "bf'", "+dd+7"),
    ("ctqs'", "bqf'", "+d7"),
    ("ctqs'", "b'", "+d+7"),
    ("ctqs'", "bqs'", "+m7"),
    ("ctqs'", "bs'", "+m+7"),
    ("ctqs'", "btqs'", "+M7"),
    ("ctqs'", "bss'", "+M+7"),
    ("ctqs'", "cff''", "+dddd+8"),
    ("ctqs'", "ctqf''", "+ddd8"),
    ("ctqs'", "cf''", "+ddd+8"),
    ("ctqs'", "cqf''", "+dd8"),
    ("ctqs'", "c''", "+dd+8"),
    ("ctqs'", "cqs''", "+d8"),
    ("ctqs'", "cs''", "+d+8"),
    ("ctqs'", "ctqs''", "+P8"),
    ("ctqs'", "css''", "+P+8"),
    ("css'", "cff", "-AAAA8"),
    ("css'", "ctqf", "-AAA+8"),
    ("css'", "cf", "-AAA8"),
    ("css'", "cqf", "-AA+8"),
    ("css'", "c", "-AA8"),
    ("css'", "cqs", "-A+8"),
    ("css'", "cs", "-A8"),
    ("css'", "ctqs", "-P+8"),
    ("css'", "css", "-P8"),
    ("css'", "dff", "-AAA7"),
    ("css'", "dtqf", "-AA+7"),
    ("css'", "df", "-AA7"),
    ("css'", "dqf", "-A+7"),
    ("css'", "d", "-A7"),
    ("css'", "dqs", "-M+7"),
    ("css'", "ds", "-M7"),
    ("css'", "dtqs", "-m+7"),
    ("css'", "dss", "-m7"),
    ("css'", "eff", "-AAA6"),
    ("css'", "etqf", "-AA+6"),
    ("css'", "ef", "-AA6"),
    ("css'", "eqf", "-A+6"),
    ("css'", "e", "-A6"),
    ("css'", "eqs", "-M+6"),
    ("css'", "es", "-M6"),
    ("css'", "etqs", "-m+6"),
    ("css'", "ess", "-m6"),
    ("css'", "fff", "-AAAA5"),
    ("css'", "ftqf", "-AAA+5"),
    ("css'", "ff", "-AAA5"),
    ("css'", "fqf", "-AA+5"),
    ("css'", "f", "-AA5"),
    ("css'", "fqs", "-A+5"),
    ("css'", "fs", "-A5"),
    ("css'", "ftqs", "-P+5"),
    ("css'", "fss", "-P5"),
    ("css'", "gff", "-AAAA4"),
    ("css'", "gtqf", "-AAA+4"),
    ("css'", "gf", "-AAA4"),
    ("css'", "gqf", "-AA+4"),
    ("css'", "g", "-AA4"),
    ("css'", "gqs", "-A+4"),
    ("css'", "gs", "-A4"),
    ("css'", "gtqs", "-P+4"),
    ("css'", "gss", "-P4"),
    ("css'", "aff", "-AAA3"),
    ("css'", "atqf", "-AA+3"),
    ("css'", "af", "-AA3"),
    ("css'", "aqf", "-A+3"),
    ("css'", "a", "-A3"),
    ("css'", "aqs", "-M+3"),
    ("css'", "as", "-M3"),
    ("css'", "atqs", "-m+3"),
    ("css'", "ass", "-m3"),
    ("css'", "bff", "-AAA2"),
    ("css'", "btqf", "-AA+2"),
    ("css'", "bf", "-AA2"),
    ("css'", "bqf", "-A+2"),
    ("css'", "b", "-A2"),
    ("css'", "bqs", "-M+2"),
    ("css'", "bs", "-M2"),
    ("css'", "btqs", "-m+2"),
    ("css'", "bss", "-m2"),
    ("css'", "cff'", "-AAAA1"),
    ("css'", "ctqf'", "-AAA+1"),
    ("css'", "cf'", "-AAA1"),
    ("css'", "cqf'", "-AA+1"),
    ("css'", "c'", "-AA1"),
    ("css'", "cqs'", "-A+1"),
    ("css'", "cs'", "-A1"),
    ("css'", "ctqs'", "-P+1"),
    ("css'", "css'", "P1"),
    ("css'", "dff'", "+ddd2"),
    ("css'", "dtqf'", "+ddd+2"),
    ("css'", "df'", "+dd2"),
    ("css'", "dqf'", "+dd+2"),
    ("css'", "d'", "+d2"),
    ("css'", "dqs'", "+d+2"),
    ("css'", "ds'", "+m2"),
    ("css'", "dtqs'", "+m+2"),
    ("css'", "dss'", "+M2"),
    ("css'", "eff'", "+ddd3"),
    ("css'", "etqf'", "+ddd+3"),
    ("css'", "ef'", "+dd3"),
    ("css'", "eqf'", "+dd+3"),
    ("css'", "e'", "+d3"),
    ("css'", "eqs'", "+d+3"),
    ("css'", "es'", "+m3"),
    ("css'", "etqs'", "+m+3"),
    ("css'", "ess'", "+M3"),
    ("css'", "fff'", "+dddd4"),
    ("css'", "ftqf'", "+dddd+4"),
    ("css'", "ff'", "+ddd4"),
    ("css'", "fqf'", "+ddd+4"),
    ("css'", "f'", "+dd4"),
    ("css'", "fqs'", "+dd+4"),
    ("css'", "fs'", "+d4"),
    ("css'", "ftqs'", "+d+4"),
    ("css'", "fss'", "+P4"),
    ("css'", "gff'", "+dddd5"),
    ("css'", "gtqf'", "+dddd+5"),
    ("css'", "gf'", "+ddd5"),
    ("css'", "gqf'", "+ddd+5"),
    ("css'", "g'", "+dd5"),
    ("css'", "gqs'", "+dd+5"),
    ("css'", "gs'", "+d5"),
    ("css'", "gtqs'", "+d+5"),
    ("css'", "gss'", "+P5"),
    ("css'", "aff'", "+ddd6"),
    ("css'", "atqf'", "+ddd+6"),
    ("css'", "af'", "+dd6"),
    ("css'", "aqf'", "+dd+6"),
    ("css'", "a'", "+d6"),
    ("css'", "aqs'", "+d+6"),
    ("css'", "as'", "+m6"),
    ("css'", "atqs'", "+m+6"),
    ("css'", "ass'", "+M6"),
    ("css'", "bff'", "+ddd7"),
    ("css'", "btqf'", "+ddd+7"),
    ("css'", "bf'", "+dd7"),
    ("css'", "bqf'", "+dd+7"),
    ("css'", "b'", "+d7"),
    ("css'", "bqs'", "+d+7"),
    ("css'", "bs'", "+m7"),
    ("css'", "btqs'", "+m+7"),
    ("css'", "bss'", "+M7"),
    ("css'", "cff''", "+dddd8"),
    ("css'", "ctqf''", "+dddd+8"),
    ("css'", "cf''", "+ddd8"),
    ("css'", "cqf''", "+ddd+8"),
    ("css'", "c''", "+dd8"),
    ("css'", "cqs''", "+dd+8"),
    ("css'", "cs''", "+d8"),
    ("css'", "ctqs''", "+d+8"),
    ("css'", "css''", "+P8"),
]


@pytest.mark.parametrize("pitch_a, pitch_b, name", values)
def test_NamedInterval_01(pitch_a, pitch_b, name):
    pitch_a = abjad.NamedPitch(pitch_a)
    pitch_b = abjad.NamedPitch(pitch_b)
    interval = abjad.NamedInterval.from_pitch_carriers(pitch_a, pitch_b)
    assert interval.name == name
    assert pitch_a.transpose(interval) == pitch_b
    assert pitch_b.transpose(-interval) == pitch_a
